==> nextcloud-29.0.12.tgz: nextcloud/apps/federation/l10n/da.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Tilføjet listen af godkendte servere",
    "Server is already in the list of trusted servers." : "Serveren står allerede på listen over sikre servere",
    "No server to federate with found" : "Der blev ikke fundet nogen server til at sammenkoble med",
    "Could not add server" : "Kunne ikke tilføje server",
    "Trusted servers" : "Pålidelige servere",
    "Federation" : "Sammenkobling",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Sammenkobling giver dig mulighed for at oprette forbindelse til andre betroede servere for at udveksle kontobiblioteket.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Sammenkobling giver dig mulighed for at oprette forbindelse til andre betroede servere for at udveksle kontobiblioteket. For eksempel vil dette blive brugt til automatisk at fuldføre eksterne konti til deling.",
    "External documentation for Federated Cloud Sharing" : "Ekstern dokumentation for Sammenkoblings Cloud deling",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Sammenkobling giver dig mulighed for at oprette forbindelse til andre betroede servere for at udveksle kontobiblioteket. For eksempel vil dette blive brugt til automatisk at fuldføre eksterne konti til sammenkoblet deling. Det er ikke nødvendigt at tilføje en server som betroet server for at oprette en sammenkoblet deling.",
    "+ Add trusted server" : "+ Tilføj pålidelig server",
    "Trusted server" : "Pålidelig server",
    "Add" : "Tilføj"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.10.tgz: nextcloud/apps/federation/l10n/da.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Tilføjet listen af godkendte servere",
    "No server found with ID: %s" : "Ingen server fundet med ID: %s",
    "Could not remove server" : "Serveren kunne ikke fjernes",
    "Server is already in the list of trusted servers." : "Serveren står allerede på listen over sikre servere",
    "No server to federate with found" : "Der blev ikke fundet nogen server til at sammenkoble med",
    "Could not add server" : "Kunne ikke tilføje server",
    "Trusted servers" : "Pålidelige servere",
    "Federation" : "Sammenkobling",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "Sammenkobling giver dig mulighed for at oprette forbindelse til andre betroede servere for at udveksle kontobiblioteket.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "Sammenkobling giver dig mulighed for at oprette forbindelse til andre betroede servere for at udveksle kontobiblioteket. For eksempel vil dette blive brugt til automatisk at fuldføre eksterne konti til deling.",
    "External documentation for Federated Cloud Sharing" : "Ekstern dokumentation for Sammenkoblings Cloud deling",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Sammenkobling giver dig mulighed for at oprette forbindelse til andre betroede servere for at udveksle kontobiblioteket. For eksempel vil dette blive brugt til automatisk at fuldføre eksterne konti til sammenkoblet deling. Det er ikke nødvendigt at tilføje en server som betroet server for at oprette en sammenkoblet deling.",
    "Each server must validate the other. This process may require a few cron cycles." : "Hver server skal validere den anden. Denne proces kan kræve et par cron cyklusser.",
    "+ Add trusted server" : "+ Tilføj pålidelig server",
    "Trusted server" : "Pålidelig server",
    "Add" : "Tilføj"
},
"nplurals=2; plural=(n != 1);");
